.. _notations-link:


Notations
---------

Figures below illustrate a flux of incident electrons, referred to as primary electrons (|PEs|), striking a sample (shown in gray) with an energy of :math:`E_{0,\,\mathrm{eV}}`.
The sample, in turn, emits electrons (emitted electrons, EEs).
The EE flux arises from three distinct physical processes.



.. _IBE-link:

Inelastic backscattering
************************

The |PE| undergoes at least one inelastic interaction and exits the sample having lost part of its energy.
Such electrons are called inelastically backscattered electrons (|IBEs|).

.. image:: ../_static/IBE.png
  :width: 300
  :align: center

|

.. _EBE-link:

Elastic backscattering
**********************

The |PE| undergoes one or more elastic interactions and is re-emitted without energy loss.
These are referred to as elastically backscattered electrons (|EBEs|).

.. image:: ../_static/EBE.png
  :width: 300
  :align: center

|

.. _SE-link:

Secondary emission
******************

The |PE| ejects one or more electrons from the material which are subsequently emitted.
By energy conservation, the sum of the energies of the secondary electrons (|SEs|) cannot exceed that of the |PE| :cite:`Furman2002,Furman2013`.

.. image:: ../_static/IBE.png
  :width: 300
  :align: center

|

The Total Electron Emission Yield (|TEEY|) is the sum of the Inelastically Backscattered Electron Emission Yield (|IBEEY|), the Elastically Backscattered Electron Emission Yield (|EBEEY|) and the Secondary Electron Emission Yield (|SEEY|).
